@@ -17,7 +17,7 @@ MooseX::MarkAsMethods - Mark overload code symbols as methods
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
 
@@ -71,7 +71,7 @@ to worry about ordering is:
 
     use base 'Moose::Meta::Method';
 
-    our $VERSION = '0.03';
+    our $VERSION = '0.04';
 
     # strictly speaking, we don't need to do this; we could just use
     # Moose::Meta::Method or even Class::MOP::Method...  But it might be
@@ -116,19 +116,19 @@ sub import {
             delete $symbols{$overload_name};
         }
 
-        ### blowing away non-methods...
-        namespace::clean->clean_subroutines($target, grep { !$methods{$_} } keys %symbols)
-            if $args{autoclean};
-        
         return;
     };
 
+    namespace::autoclean->import(-cleanee => $target)
+        if $args{autoclean};
+
     return;
 }
 
 =head1 SEE ALSO
 
-L<B::Hooks::EndOfScope>, L<namespace::autoclean>, L<Class::MOP>, L<Moose>.
+L<overload>, L<B::Hooks::EndOfScope>, L<namespace::autoclean>, L<Class::MOP>,
+L<Moose>.
 
 =head1 AUTHOR
 
